@@ -85,61 +85,53 @@ from .token import TokenType
 #           20
 
 class TreeNode:
-    # Not so nice, hack so as not to have to pass var_dict
-    # recursively to evalute call
-    var_dict = {}
-
-    @staticmethod
-    def set_var_dict(var_dict):
-        TreeNode.var_dict = var_dict
-
     def __init__(self, token):
         self.token = token
         self.children = []
 
-    def evaluate(self):
+    def evaluate(self, var_dict={}):
         if self.token.ttype == TokenType.AND:
-            return self.children[0].evaluate() and self.children[1].evaluate()
+            return self.children[0].evaluate(var_dict) and self.children[1].evaluate(var_dict)
         elif self.token.ttype == TokenType.OR:
-            return self.children[0].evaluate() or self.children[1].evaluate()
+            return self.children[0].evaluate(var_dict) or self.children[1].evaluate(var_dict)
         elif self.token.ttype == TokenType.NOT:
-            return not self.children[0].evaluate()
+            return not self.children[0].evaluate(var_dict)
         elif self.token.ttype == TokenType.TRUE:
             return True
         elif self.token.ttype == TokenType.FALSE:
             return False
         elif self.token.ttype == TokenType.CONTAINS:
-            return self.children[1].evaluate() in self.children[0].evaluate()
+            return self.children[1].evaluate(var_dict) in self.children[0].evaluate(var_dict)
         elif self.token.ttype == TokenType.STARTSWITH:
-            return self.children[0].evaluate().startswith(self.children[1].evaluate())
+            return self.children[0].evaluate(var_dict).startswith(self.children[1].evaluate(var_dict))
         elif self.token.ttype == TokenType.ENDSWITH:
-            return self.children[0].evaluate().endswith(self.children[1].evaluate())
+            return self.children[0].evaluate(var_dict).endswith(self.children[1].evaluate(var_dict))
         elif self.token.ttype == TokenType.LOWER:
-            return self.children[0].evaluate().lower()
+            return self.children[0].evaluate(var_dict).lower()
         elif self.token.ttype == TokenType.UPPER:
-            return self.children[0].evaluate().upper()
+            return self.children[0].evaluate(var_dict).upper()
         elif self.token.ttype == TokenType.LEN:
-            return len(self.children[0].evaluate())
+            return len(self.children[0].evaluate(var_dict))
         elif self.token.ttype == TokenType.EQ:
-            return self.children[0].evaluate() == self.children[1].evaluate()
+            return self.children[0].evaluate(var_dict) == self.children[1].evaluate(var_dict)
         elif self.token.ttype == TokenType.NOTEQ:
-            return self.children[0].evaluate() != self.children[1].evaluate()
+            return self.children[0].evaluate(var_dict) != self.children[1].evaluate(var_dict)
         elif self.token.ttype == TokenType.LT:
-            return self.children[0].evaluate() < self.children[1].evaluate()
+            return self.children[0].evaluate(var_dict) < self.children[1].evaluate(var_dict)
         elif self.token.ttype == TokenType.LTEQ:
-            return self.children[0].evaluate() <= self.children[1].evaluate()
+            return self.children[0].evaluate(var_dict) <= self.children[1].evaluate(var_dict)
         elif self.token.ttype == TokenType.GT:
-            return self.children[0].evaluate() > self.children[1].evaluate()
+            return self.children[0].evaluate(var_dict) > self.children[1].evaluate(var_dict)
         elif self.token.ttype == TokenType.GTEQ:
-            return self.children[0].evaluate() >= self.children[1].evaluate()
+            return self.children[0].evaluate(var_dict) >= self.children[1].evaluate(var_dict)
         elif self.token.ttype == TokenType.NUMBER:
             return self.numeric_value(self.token.ttext)
         elif self.token.ttype == TokenType.STRING:
             return self.token.ttext
         elif self.token.ttype == TokenType.VARIABLE:
-            if self.token.ttext not in TreeNode.var_dict:
+            if self.token.ttext not in var_dict:
                 raise ValueError(f"Variable {self.token.ttext} not found in dictionary.")
-            return TreeNode.var_dict[self.token.ttext]
+            return var_dict[self.token.ttext]
 
     # method to print the tree
     def traverse(self, level=0):
