@@ -36,15 +36,11 @@ class TokenType(Enum):
 
 
 class Token:
-    def __init__(self, ttext, ttype, start_pos=None, end_pos=None):
+    def __init__(self, ttext, ttype):
         # token text for token types VARIABLE, STRING and NUMBER is
         # necessary; for other token types it is kind-of redundant
         self.ttext = ttext
         self.ttype = ttype
-        # Gives start and end position of token in expression if it is a variables
-        # For expression "de" == ${conv.lang}
-        self.start_pos = start_pos
-        self.end_pos = end_pos
 
     token_map = {
         "and": TokenType.AND,
